summaryrefslogtreecommitdiff
path: root/binaryninjaapi.h
diff options
context:
space:
mode:
Diffstat (limited to 'binaryninjaapi.h')
-rw-r--r--binaryninjaapi.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/binaryninjaapi.h b/binaryninjaapi.h
index 6c9f8514..c36e21a2 100644
--- a/binaryninjaapi.h
+++ b/binaryninjaapi.h
@@ -3176,14 +3176,14 @@ namespace BinaryNinja {
/*! Get the BinaryView for a specific View type
- \param name View name. e.g. ``Linear:ELF``, ``Graph:PE``
+ \param name View type. e.g. ``ELF``, ``PE``
\return The BinaryView, if it exists
*/
BinaryNinja::Ref<BinaryNinja::BinaryView> GetViewOfType(const std::string& name);
- /*! List of View names that exist within the current file
+ /*! List of View types that exist within the current file
- \return List of View Names
+ \return List of View Types
*/
std::vector<std::string> GetExistingViews() const;